@@ -6,7 +6,7 @@
     <message>
         <location filename="../qml/About.qml" line="27"/>
         <source>About %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Über %1</translation>
     </message>
     <message>
         <location filename="../qml/About.qml" line="46"/>
@@ -21,17 +21,22 @@
     <message>
         <location filename="../qml/About.qml" line="73"/>
         <source>Using Qt %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Verwendet Qt %1</translation>
     </message>
     <message>
         <location filename="../qml/About.qml" line="87"/>
         <source>Webcam capture application.</source>
-        <translation>Webcam Aufnahmewerkzeug.</translation>
+        <translation>Webcam-Aufnahmeanwendung.</translation>
     </message>
     <message>
         <location filename="../qml/About.qml" line="90"/>
         <source>A simple webcam application for picture and video capture.</source>
-        <translation>Ein einfaches Program um mit einer Webcam Bilder und Videos aufzunehmen.</translation>
+        <translation>Ein einfache Webcam-Anwendung für die Bild- und Videoaufnahme.</translation>
+    </message>
+    <message>
+        <location filename="../qml/About.qml" line="103"/>
+        <source>Thanks!</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../qml/About.qml" line="79"/>
@@ -39,17 +44,12 @@
         <translation>Webseite</translation>
     </message>
     <message>
-        <location filename="../qml/About.qml" line="103"/>
-        <source>Contributors</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../qml/About.qml" line="133"/>
+        <location filename="../qml/About.qml" line="115"/>
         <source>License</source>
         <translation>Lizenz</translation>
     </message>
     <message>
-        <location filename="../qml/About.qml" line="144"/>
+        <location filename="../qml/About.qml" line="126"/>
         <source>Close</source>
         <translation>Schließen</translation>
     </message>
@@ -59,7 +59,7 @@
     <message>
         <location filename="../qml/AddMedia.qml" line="28"/>
         <source>Add new media</source>
-        <translation>Medien hinzufügen</translation>
+        <translation>Neue Medien hinzufügen</translation>
     </message>
     <message>
         <location filename="../qml/AddMedia.qml" line="65"/>
@@ -69,17 +69,17 @@
     <message>
         <location filename="../qml/AddMedia.qml" line="72"/>
         <source>Insert media description</source>
-        <translation>Eingabe einer Beschreibung der Medienquelle</translation>
+        <translation>Medienbeschreibung eingeben</translation>
     </message>
     <message>
         <location filename="../qml/AddMedia.qml" line="79"/>
         <source>Media file</source>
-        <translation>Medienquelldatei</translation>
+        <translation>Mediendatei</translation>
     </message>
     <message>
         <location filename="../qml/AddMedia.qml" line="87"/>
         <source>Select media file</source>
-        <translation>Auswählen der Medienquelldatei</translation>
+        <translation>Mediendatei auswählen</translation>
     </message>
     <message>
         <location filename="../qml/AddMedia.qml" line="94"/>
@@ -99,72 +99,72 @@
     <message>
         <location filename="../qml/AddMedia.qml" line="153"/>
         <source>Choose the file to add as media</source>
-        <translation>Auswählen der hinzuzufügenden Medienquelldatei</translation>
+        <translation>Wählen Sie die Datei aus, die als Medium hinzugefügt werden soll</translation>
     </message>
 </context>
 <context>
     <name>AudioConfig</name>
     <message>
-        <location filename="../qml/AudioConfig.qml" line="110"/>
+        <location filename="../qml/AudioConfig.qml" line="116"/>
         <source>Outputs</source>
-        <translation type="unfinished"></translation>
+        <translation>Ausgaben</translation>
     </message>
     <message>
-        <location filename="../qml/AudioConfig.qml" line="113"/>
+        <location filename="../qml/AudioConfig.qml" line="119"/>
         <source>Select the output device for audio playing</source>
-        <translation type="unfinished"></translation>
+        <translation>Wählen Sie das Ausgabegerät für die Audiowiedergabe aus</translation>
     </message>
     <message>
-        <location filename="../qml/AudioConfig.qml" line="127"/>
+        <location filename="../qml/AudioConfig.qml" line="133"/>
         <source>Inputs</source>
-        <translation type="unfinished"></translation>
+        <translation>Eingaben</translation>
     </message>
     <message>
-        <location filename="../qml/AudioConfig.qml" line="129"/>
+        <location filename="../qml/AudioConfig.qml" line="135"/>
         <source>Select the device for audio capturing</source>
-        <translation type="unfinished"></translation>
+        <translation>Wählen Sie das Gerät für die Audioaufnahme aus</translation>
     </message>
     <message>
-        <location filename="../qml/AudioConfig.qml" line="186"/>
-        <location filename="../qml/AudioConfig.qml" line="288"/>
+        <location filename="../qml/AudioConfig.qml" line="192"/>
+        <location filename="../qml/AudioConfig.qml" line="294"/>
         <source>Silence</source>
-        <translation type="unfinished"></translation>
+        <translation>Stille</translation>
     </message>
 </context>
 <context>
     <name>AudioInfo</name>
     <message>
-        <location filename="../qml/AudioInfo.qml" line="162"/>
+        <location filename="../qml/AudioInfo.qml" line="168"/>
         <source>Description</source>
-        <translation type="unfinished">Beschreibung</translation>
+        <translation>Beschreibung</translation>
     </message>
     <message>
-        <location filename="../qml/AudioInfo.qml" line="177"/>
-        <location filename="../qml/AudioInfo.qml" line="184"/>
+        <location filename="../qml/AudioInfo.qml" line="183"/>
+        <location filename="../qml/AudioInfo.qml" line="190"/>
         <source>Device description</source>
-        <translation type="unfinished"></translation>
+        <translation>Gerätebeschreibung</translation>
     </message>
     <message>
-        <location filename="../qml/AudioInfo.qml" line="192"/>
-        <location filename="../qml/AudioInfo.qml" line="207"/>
-        <location filename="../qml/AudioInfo.qml" line="214"/>
+        <location filename="../qml/AudioInfo.qml" line="198"/>
+        <location filename="../qml/AudioInfo.qml" line="213"/>
+        <location filename="../qml/AudioInfo.qml" line="220"/>
         <source>Device id</source>
-        <translation type="unfinished"></translation>
+        <translation>Gerätekennung</translation>
     </message>
     <message>
-        <location filename="../qml/AudioInfo.qml" line="229"/>
+        <location filename="../qml/AudioInfo.qml" line="235"/>
         <source>Sample Format</source>
-        <translation type="unfinished"></translation>
+        <translation>Abtastformat</translation>
     </message>
     <message>
-        <location filename="../qml/AudioInfo.qml" line="255"/>
+        <location filename="../qml/AudioInfo.qml" line="261"/>
         <source>Channels</source>
-        <translation type="unfinished"></translation>
+        <translation>Kanäle</translation>
     </message>
     <message>
-        <location filename="../qml/AudioInfo.qml" line="281"/>
+        <location filename="../qml/AudioInfo.qml" line="287"/>
         <source>Sample Rate</source>
-        <translation type="unfinished"></translation>
+        <translation>Abtastrate</translation>
     </message>
 </context>
 <context>
@@ -172,12 +172,12 @@
     <message>
         <location filename="../qml/ConfigBar.qml" line="44"/>
         <source>Output</source>
-        <translation type="unfinished"></translation>
+        <translation>Ausgabe</translation>
     </message>
     <message>
         <location filename="../qml/ConfigBar.qml" line="48"/>
         <source>General Options</source>
-        <translation type="unfinished"></translation>
+        <translation>Allgemeine Optionen</translation>
     </message>
     <message>
         <location filename="../qml/ConfigBar.qml" line="52"/>
@@ -187,7 +187,7 @@
     <message>
         <location filename="../qml/ConfigBar.qml" line="56"/>
         <source>Updates</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktualisierungen</translation>
     </message>
 </context>
 <context>
@@ -195,7 +195,7 @@
     <message>
         <location filename="../qml/EffectBar.qml" line="121"/>
         <source>Search effect...</source>
-        <translation>Effektsuche...</translation>
+        <translation>Effekt suchen...</translation>
     </message>
     <message>
         <location filename="../qml/EffectBar.qml" line="167"/>
@@ -235,62 +235,67 @@
 <context>
     <name>GeneralConfig</name>
     <message>
-        <location filename="../qml/GeneralConfig.qml" line="37"/>
+        <location filename="../qml/GeneralConfig.qml" line="38"/>
         <source>Play webcam on start</source>
-        <translation type="unfinished"></translation>
+        <translation>Webcam beim Start wiedergeben</translation>
     </message>
     <message>
-        <location filename="../qml/GeneralConfig.qml" line="43"/>
+        <location filename="../qml/GeneralConfig.qml" line="44"/>
         <source>Enable advanced effects mode</source>
-        <translation type="unfinished"></translation>
+        <translation>Erweiterten Effektmodus aktivieren</translation>
     </message>
     <message>
-        <location filename="../qml/GeneralConfig.qml" line="49"/>
+        <location filename="../qml/GeneralConfig.qml" line="50"/>
         <source>Frameworks &amp; libraries</source>
-        <translation type="unfinished"></translation>
+        <translation>Programmiergerüste &amp; Bibliotheken</translation>
     </message>
     <message>
-        <location filename="../qml/GeneralConfig.qml" line="59"/>
+        <location filename="../qml/GeneralConfig.qml" line="60"/>
         <source>Video capture</source>
+        <translation>Videoaufnahme</translation>
+    </message>
+    <message>
+        <location filename="../qml/GeneralConfig.qml" line="70"/>
+        <source>Desktop capture</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qml/GeneralConfig.qml" line="69"/>
+        <location filename="../qml/GeneralConfig.qml" line="80"/>
         <source>Audio capture/play</source>
-        <translation type="unfinished"></translation>
+        <translation>Audioaufnahme/-wiedergabe</translation>
     </message>
     <message>
-        <location filename="../qml/GeneralConfig.qml" line="79"/>
+        <location filename="../qml/GeneralConfig.qml" line="90"/>
         <source>Video convert</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qml/GeneralConfig.qml" line="89"/>
+        <location filename="../qml/GeneralConfig.qml" line="100"/>
         <source>Audio convert</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qml/GeneralConfig.qml" line="99"/>
+        <location filename="../qml/GeneralConfig.qml" line="110"/>
         <source>Video output</source>
-        <translation type="unfinished"></translation>
+        <translation>Videoausgabe</translation>
     </message>
     <message>
-        <location filename="../qml/GeneralConfig.qml" line="109"/>
+        <location filename="../qml/GeneralConfig.qml" line="120"/>
         <source>Video output convert</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qml/GeneralConfig.qml" line="119"/>
+        <location filename="../qml/GeneralConfig.qml" line="130"/>
         <source>Video playback</source>
-        <translation type="unfinished"></translation>
+        <translation>Videowiedergabe</translation>
     </message>
     <message>
-        <location filename="../qml/GeneralConfig.qml" line="129"/>
+        <location filename="../qml/GeneralConfig.qml" line="140"/>
         <source>Video record</source>
-        <translation type="unfinished"></translation>
+        <translation>Videoaufnahme</translation>
     </message>
     <message>
-        <location filename="../qml/GeneralConfig.qml" line="139"/>
+        <location filename="../qml/GeneralConfig.qml" line="150"/>
         <source>Root method</source>
         <translation type="unfinished"></translation>
     </message>
@@ -300,7 +305,7 @@
     <message>
         <location filename="../qml/MediaBar.qml" line="62"/>
         <source>No webcams found</source>
-        <translation type="unfinished"></translation>
+        <translation>Keine Webcams gefunden</translation>
     </message>
 </context>
 <context>
@@ -313,17 +318,17 @@
     <message>
         <location filename="../qml/MediaConfig.qml" line="60"/>
         <source>Insert media description</source>
-        <translation>Medienquellenbeschreibung hinzufügen</translation>
+        <translation>Medienbeschreibung eingeben</translation>
     </message>
     <message>
         <location filename="../qml/MediaConfig.qml" line="67"/>
         <source>Media file</source>
-        <translation>Medienquelldatei</translation>
+        <translation>Mediendatei</translation>
     </message>
     <message>
         <location filename="../qml/MediaConfig.qml" line="74"/>
         <source>Select media file</source>
-        <translation>Medienquelldatei auswählen</translation>
+        <translation>Mediendatei auswählen</translation>
     </message>
     <message>
         <location filename="../qml/MediaConfig.qml" line="89"/>
@@ -341,7 +346,7 @@
     <message>
         <location filename="../qml/OutputConfig.qml" line="40"/>
         <source>Virtual camera</source>
-        <translation type="unfinished"></translation>
+        <translation>Virtuelle Kamera</translation>
     </message>
 </context>
 <context>
@@ -349,27 +354,27 @@
     <message>
         <location filename="../qml/PhotoWidget.qml" line="36"/>
         <source>%1 seconds</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 Sekunden</translation>
     </message>
     <message>
         <location filename="../qml/PhotoWidget.qml" line="57"/>
         <source>Now</source>
-        <translation type="unfinished"></translation>
+        <translation>Jetzt</translation>
     </message>
     <message>
         <location filename="../qml/PhotoWidget.qml" line="81"/>
         <source>Cancel</source>
-        <translation type="unfinished">Abbrechen</translation>
+        <translation>Abbrechen</translation>
     </message>
     <message>
         <location filename="../qml/PhotoWidget.qml" line="81"/>
         <source>Shot!</source>
-        <translation type="unfinished"></translation>
+        <translation>Schuss!</translation>
     </message>
     <message>
         <location filename="../qml/PhotoWidget.qml" line="112"/>
         <source>Use flash</source>
-        <translation type="unfinished"></translation>
+        <translation>Blitz verwenden</translation>
     </message>
 </context>
 <context>
@@ -381,7 +386,7 @@
     </message>
     <message>
         <location filename="../qml/PluginConfig.qml" line="96"/>
-        <source>Search paths</source>
+        <source>Extra search paths</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -392,17 +397,17 @@
     <message>
         <location filename="../qml/PluginConfig.qml" line="114"/>
         <source>Add</source>
-        <translation type="unfinished">Hinzufügen</translation>
+        <translation>Hinzufügen</translation>
     </message>
     <message>
         <location filename="../qml/PluginConfig.qml" line="122"/>
         <source>Remove</source>
-        <translation type="unfinished">Entfernen</translation>
+        <translation>Entfernen</translation>
     </message>
     <message>
         <location filename="../qml/PluginConfig.qml" line="159"/>
         <source>Search path</source>
-        <translation type="unfinished"></translation>
+        <translation>Pfad suchen</translation>
     </message>
     <message>
         <location filename="../qml/PluginConfig.qml" line="166"/>
@@ -412,17 +417,17 @@
     <message>
         <location filename="../qml/PluginConfig.qml" line="174"/>
         <source>Refresh</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktualisieren</translation>
     </message>
     <message>
         <location filename="../qml/PluginConfig.qml" line="185"/>
         <source>Disable</source>
-        <translation type="unfinished"></translation>
+        <translation>Deaktivieren</translation>
     </message>
     <message>
         <location filename="../qml/PluginConfig.qml" line="185"/>
         <source>Enable</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktivieren</translation>
     </message>
     <message>
         <location filename="../qml/PluginConfig.qml" line="255"/>
@@ -440,30 +445,30 @@
     <message>
         <location filename="../../src/clioptions.cpp" line="32"/>
         <source>Webcam capture application.</source>
-        <translation type="unfinished">Webcam Aufnahmewerkzeug.</translation>
+        <translation>Webcam-Aufnahmeanwendung.</translation>
     </message>
     <message>
         <location filename="../../src/clioptions.cpp" line="36"/>
         <source>Load settings from PATH. If PATH is empty, load configs from application directory.</source>
-        <translation type="unfinished"></translation>
+        <translation>Einstellungen aus PATH laden. Konfigurationen aus Anwendungsverzeichnis laden, wenn PATH leer ist.</translation>
     </message>
     <message>
         <location filename="../../src/clioptions.cpp" line="44"/>
-        <source>Path to search the Qml interface.</source>
+        <source>Semi-colon separated list of paths to search the Qml interface.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/clioptions.cpp" line="52"/>
+        <location filename="../../src/clioptions.cpp" line="53"/>
         <source>Search in the specified plugins paths recursively.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/clioptions.cpp" line="58"/>
+        <location filename="../../src/clioptions.cpp" line="59"/>
         <source>Semi-colon separated list of paths to search for plugins.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/clioptions.cpp" line="65"/>
+        <location filename="../../src/clioptions.cpp" line="66"/>
         <source>Semi-colon separated list of paths to avoid loading.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -473,7 +478,7 @@
     <message>
         <location filename="../qml/RecordBar.qml" line="100"/>
         <source>Search format...</source>
-        <translation type="unfinished"></translation>
+        <translation>Format suchen...</translation>
     </message>
 </context>
 <context>
@@ -486,13 +491,13 @@
     <message>
         <location filename="../qml/RecordConfig.qml" line="87"/>
         <source>Stop recording video</source>
-        <translation>Videoaufahme Stop</translation>
+        <translation>Aufnahme des Videos stoppen</translation>
     </message>
     <message>
         <location filename="../qml/RecordConfig.qml" line="90"/>
         <location filename="../qml/RecordConfig.qml" line="123"/>
         <source>Start recording video</source>
-        <translation>Videoaufnahme Start</translation>
+        <translation>Aufnahme des Videos starten</translation>
     </message>
     <message>
         <location filename="../qml/RecordConfig.qml" line="98"/>
@@ -502,7 +507,7 @@
     <message>
         <location filename="../qml/RecordConfig.qml" line="105"/>
         <source>Insert format description</source>
-        <translation>Formatbeschreibung hinzufügen</translation>
+        <translation>Formatbeschreibung eingeben</translation>
     </message>
     <message>
         <location filename="../qml/RecordConfig.qml" line="188"/>
@@ -513,37 +518,37 @@
 <context>
     <name>Recording</name>
     <message>
-        <location filename="../../src/recording.cpp" line="606"/>
+        <location filename="../../src/recording.cpp" line="577"/>
         <source>Audio</source>
-        <translation type="unfinished"></translation>
+        <translation>Audio</translation>
     </message>
     <message>
-        <location filename="../../src/recording.cpp" line="607"/>
+        <location filename="../../src/recording.cpp" line="578"/>
         <source>Video</source>
-        <translation type="unfinished"></translation>
+        <translation>Video</translation>
     </message>
     <message>
-        <location filename="../../src/recording.cpp" line="608"/>
+        <location filename="../../src/recording.cpp" line="579"/>
         <source>Subtitle</source>
-        <translation type="unfinished"></translation>
+        <translation>Untertitel</translation>
     </message>
     <message>
-        <location filename="../../src/recording.cpp" line="665"/>
-        <location filename="../../src/recording.cpp" line="831"/>
+        <location filename="../../src/recording.cpp" line="634"/>
+        <location filename="../../src/recording.cpp" line="800"/>
         <source>audio</source>
-        <translation type="unfinished"></translation>
+        <translation>Audio</translation>
     </message>
     <message>
-        <location filename="../../src/recording.cpp" line="666"/>
-        <location filename="../../src/recording.cpp" line="832"/>
+        <location filename="../../src/recording.cpp" line="635"/>
+        <location filename="../../src/recording.cpp" line="801"/>
         <source>video</source>
-        <translation type="unfinished"></translation>
+        <translation>Video</translation>
     </message>
     <message>
-        <location filename="../../src/recording.cpp" line="667"/>
-        <location filename="../../src/recording.cpp" line="833"/>
+        <location filename="../../src/recording.cpp" line="636"/>
+        <location filename="../../src/recording.cpp" line="802"/>
         <source>subtitle</source>
-        <translation type="unfinished"></translation>
+        <translation>Untertitel</translation>
     </message>
 </context>
 <context>
@@ -551,52 +556,52 @@
     <message>
         <location filename="../qml/UpdatesConfig.qml" line="67"/>
         <source>Notify about new versions</source>
-        <translation type="unfinished"></translation>
+        <translation>Über neue Versionen benachrichtigen</translation>
     </message>
     <message>
         <location filename="../qml/UpdatesConfig.qml" line="77"/>
         <source>Check new versions</source>
-        <translation type="unfinished"></translation>
+        <translation>Auf neue Versionen prüfen</translation>
     </message>
     <message>
         <location filename="../qml/UpdatesConfig.qml" line="85"/>
         <source>Daily</source>
-        <translation type="unfinished"></translation>
+        <translation>Täglich</translation>
     </message>
     <message>
         <location filename="../qml/UpdatesConfig.qml" line="89"/>
         <source>Every two days</source>
-        <translation type="unfinished"></translation>
+        <translation>Alle zwei Tage</translation>
     </message>
     <message>
         <location filename="../qml/UpdatesConfig.qml" line="93"/>
         <source>Weekly</source>
-        <translation type="unfinished"></translation>
+        <translation>Wöchentlich</translation>
     </message>
     <message>
         <location filename="../qml/UpdatesConfig.qml" line="97"/>
         <source>Every two weeks</source>
-        <translation type="unfinished"></translation>
+        <translation>Alle zwei Wochen</translation>
     </message>
     <message>
         <location filename="../qml/UpdatesConfig.qml" line="101"/>
         <source>Monthly</source>
-        <translation type="unfinished"></translation>
+        <translation>Monatlich</translation>
     </message>
     <message>
         <location filename="../qml/UpdatesConfig.qml" line="105"/>
         <source>Never</source>
-        <translation type="unfinished"></translation>
+        <translation>Nie</translation>
     </message>
     <message>
         <location filename="../qml/UpdatesConfig.qml" line="116"/>
         <source>Last updated</source>
-        <translation type="unfinished"></translation>
+        <translation>Letzte Aktualisierung</translation>
     </message>
     <message>
         <location filename="../qml/UpdatesConfig.qml" line="137"/>
         <source>Your version of %1 is outdated. Latest version is &lt;b&gt;%2&lt;/b&gt;.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ihre Version von %1 ist veraltet. Neueste Version ist &lt;b&gt;%2&lt;/b&gt;.</translation>
     </message>
     <message>
         <location filename="../qml/UpdatesConfig.qml" line="143"/>
@@ -606,12 +611,12 @@
     <message>
         <location filename="../qml/UpdatesConfig.qml" line="159"/>
         <source>Thanks for using a &lt;b&gt;development version&lt;/b&gt;!&lt;br /&gt;It will be very helpful if you can report any bug and suggestions you have.</source>
-        <translation type="unfinished"></translation>
+        <translation>Danke für die Verwendung einer &lt;b&gt;Entwicklungsversion&lt;/b&gt;!&lt;br /&gt;Es wäre sehr hilfreich, wenn Sie irgendwelche Fehler und Vorschläge, die Sie haben, melden.</translation>
     </message>
     <message>
         <location filename="../qml/UpdatesConfig.qml" line="164"/>
         <source>Report a Bug</source>
-        <translation type="unfinished"></translation>
+        <translation>Fehler melden</translation>
     </message>
 </context>
 <context>
@@ -619,7 +624,7 @@
     <message>
         <location filename="../qml/main.qml" line="172"/>
         <source>Recording</source>
-        <translation type="unfinished"></translation>
+        <translation>Aufnahme</translation>
     </message>
     <message>
         <location filename="../qml/main.qml" line="111"/>
@@ -640,32 +645,32 @@
     <message>
         <location filename="../qml/main.qml" line="71"/>
         <source>New version available!</source>
-        <translation type="unfinished"></translation>
+        <translation>Neue Version verfügbar!</translation>
     </message>
     <message>
         <location filename="../qml/main.qml" line="72"/>
         <source>Download %1 %2 NOW!</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 %2 JETZT herunterladen!</translation>
     </message>
     <message>
         <location filename="../qml/main.qml" line="107"/>
         <source>Stop</source>
-        <translation type="unfinished"></translation>
+        <translation>Stopp</translation>
     </message>
     <message>
         <location filename="../qml/main.qml" line="570"/>
         <source>Go back</source>
-        <translation type="unfinished"></translation>
+        <translation>Zurückgehen</translation>
     </message>
     <message>
         <location filename="../qml/main.qml" line="624"/>
         <source>Configure sources</source>
-        <translation type="unfinished"></translation>
+        <translation>Quellen konfigurieren</translation>
     </message>
     <message>
         <location filename="../qml/main.qml" line="637"/>
         <source>Configure audio</source>
-        <translation type="unfinished"></translation>
+        <translation>Audio konfigurieren</translation>
     </message>
     <message>
         <location filename="../qml/main.qml" line="664"/>
