@@ -46,7 +46,8 @@ AudioLayer::AudioLayer(QQmlApplicationEngine *engine, QObject *parent):
     for (int rate = 11025; rate < MAX_SAMPLE_RATE; rate *= 2)
         this->m_commonSampleRates << rate;
 
-    qSort(this->m_commonSampleRates);
+    std::sort(this->m_commonSampleRates.begin(),
+              this->m_commonSampleRates.end());
 
     this->m_inputState = AkElement::ElementStateNull;
     this->setQmlEngine(engine);
