@@ -106,6 +106,10 @@ MediaSource::MediaSource(QQmlApplicationEngine *engine, QObject *parent):
                          SIGNAL(error(const QString &)),
                          this,
                          SIGNAL(error(const QString &)));
+        QObject::connect(this->m_desktopCapture.data(),
+                         SIGNAL(captureLibChanged(const QString &)),
+                         this,
+                         SLOT(saveDesktopCaptureCaptureLib(const QString &)));
     }
 
     if (this->m_uriCapture) {
@@ -119,6 +123,24 @@ MediaSource::MediaSource(QQmlApplicationEngine *engine, QObject *parent):
                          SLOT(saveMultiSrcCodecLib(const QString &)));
     }
 
+    this->m_syphonCapture = AkElement::create("SyphonIO");
+
+    if (this->m_syphonCapture) {
+        QObject::connect(this->m_syphonCapture.data(),
+                         SIGNAL(oStream(const AkPacket &)),
+                         this,
+                         SIGNAL(oStream(const AkPacket &)),
+                         Qt::DirectConnection);
+        QObject::connect(this->m_syphonCapture.data(),
+                         SIGNAL(mediasChanged(const QStringList &)),
+                         this,
+                         SLOT(updateStreams()));
+        QObject::connect(this->m_syphonCapture.data(),
+                         SIGNAL(error(const QString &)),
+                         this,
+                         SIGNAL(error(const QString &)));
+    }
+
     // Setup streams
     QStringList cameras;
 
@@ -134,6 +156,13 @@ MediaSource::MediaSource(QQmlApplicationEngine *engine, QObject *parent):
                                   "medias",
                                   Q_RETURN_ARG(QStringList, desktops));
 
+    QStringList syphonServers;
+
+    if (this->m_syphonCapture)
+        QMetaObject::invokeMethod(this->m_syphonCapture.data(),
+                                  "medias",
+                                  Q_RETURN_ARG(QStringList, syphonServers));
+
     for (const QString &camera: cameras) {
         QString description;
 
@@ -156,9 +185,22 @@ MediaSource::MediaSource(QQmlApplicationEngine *engine, QObject *parent):
         this->m_descriptions[desktop] = description;
     }
 
+    if (this->m_syphonCapture)
+        for (const QString &server: syphonServers) {
+            QString description;
+
+            QMetaObject::invokeMethod(this->m_syphonCapture.data(),
+                                      "description",
+                                      Q_RETURN_ARG(QString, description),
+                                      Q_ARG(QString, server));
+
+            this->m_descriptions[server] = description;
+        }
+
     this->m_cameras = cameras;
     this->m_desktops = desktops;
-    this->m_streams = cameras + desktops;
+    this->m_syphonServers = syphonServers;
+    this->m_streams = cameras + syphonServers + desktops;
 
     this->loadProperties();
 }
@@ -184,6 +226,11 @@ QStringList MediaSource::cameras() const
     return this->m_cameras;
 }
 
+QStringList MediaSource::syphonServers() const
+{
+    return this->m_syphonServers;
+}
+
 QStringList MediaSource::desktops() const
 {
     return this->m_desktops;
@@ -223,13 +270,13 @@ bool MediaSource::embedControls(const QString &where,
                                 const QString &stream,
                                 const QString &name) const
 {
-    auto effect = this->sourceElement(stream);
+    auto source = this->sourceElement(stream);
 
-    if (!effect)
+    if (!source)
         return false;
 
-    auto interface = effect->controlInterface(this->m_engine,
-                                              effect->pluginId());
+    auto interface = source->controlInterface(this->m_engine,
+                                              source->pluginId());
 
     if (!interface)
         return false;
@@ -249,7 +296,6 @@ bool MediaSource::embedControls(const QString &where,
 
         // Finally, embed the plugin item UI in the desired place.
         interfaceItem->setParentItem(item);
-        interfaceItem->setParent(item);
 
         QQmlProperty::write(interfaceItem,
                             "anchors.fill",
@@ -275,8 +321,8 @@ void MediaSource::removeInterface(const QString &where) const
         QList<decltype(item)> childItems = item->childItems();
 
         for (auto child: childItems) {
-            child->setParentItem(NULL);
-            child->setParent(NULL);
+            child->setParentItem(nullptr);
+            child->setParent(nullptr);
             delete child;
         }
     }
@@ -290,6 +336,8 @@ AkElementPtr MediaSource::sourceElement(const QString &stream) const
         return this->m_desktopCapture;
     else if (this->m_uris.contains(stream))
         return this->m_uriCapture;
+    else if (this->m_syphonServers.contains(stream))
+        return this->m_syphonCapture;
 
     return AkElementPtr();
 }
@@ -327,6 +375,9 @@ void MediaSource::setState(AkElement::ElementState state)
         if (this->m_uriCapture)
             this->m_uriCapture->setState(AkElement::ElementStateNull);
 
+        if (this->m_syphonCapture)
+            this->m_syphonCapture->setState(AkElement::ElementStateNull);
+
         source = this->m_cameraCapture;
     } else if (this->m_desktops.contains(this->m_stream)) {
         if (this->m_cameraCapture)
@@ -335,6 +386,9 @@ void MediaSource::setState(AkElement::ElementState state)
         if (this->m_uriCapture)
             this->m_uriCapture->setState(AkElement::ElementStateNull);
 
+        if (this->m_syphonCapture)
+            this->m_syphonCapture->setState(AkElement::ElementStateNull);
+
         source = this->m_desktopCapture;
     } else if (this->m_uris.contains(this->m_stream)) {
         if (this->m_cameraCapture)
@@ -343,7 +397,21 @@ void MediaSource::setState(AkElement::ElementState state)
         if (this->m_desktopCapture)
             this->m_desktopCapture->setState(AkElement::ElementStateNull);
 
+        if (this->m_syphonCapture)
+            this->m_syphonCapture->setState(AkElement::ElementStateNull);
+
         source = this->m_uriCapture;
+    } else if (this->m_syphonServers.contains(this->m_stream)) {
+        if (this->m_cameraCapture)
+            this->m_cameraCapture->setState(AkElement::ElementStateNull);
+
+        if (this->m_desktopCapture)
+            this->m_desktopCapture->setState(AkElement::ElementStateNull);
+
+        if (this->m_uriCapture)
+            this->m_uriCapture->setState(AkElement::ElementStateNull);
+
+        source = this->m_syphonCapture;
     }
 
     if (source) {
@@ -494,6 +562,13 @@ void MediaSource::updateStreams()
                                   "medias",
                                   Q_RETURN_ARG(QStringList, desktops));
 
+    QStringList syphonServers;
+
+    if (this->m_syphonCapture)
+        QMetaObject::invokeMethod(this->m_syphonCapture.data(),
+                                  "medias",
+                                  Q_RETURN_ARG(QStringList, syphonServers));
+
     this->m_descriptions.clear();
 
     for (const QString &camera: cameras) {
@@ -521,9 +596,21 @@ void MediaSource::updateStreams()
     for (const QString &uri: this->m_uris.keys())
         this->m_descriptions[uri] = this->m_uris[uri].toString();
 
+    for (const QString &server: syphonServers) {
+        QString description;
+
+        QMetaObject::invokeMethod(this->m_syphonCapture.data(),
+                                  "description",
+                                  Q_RETURN_ARG(QString, description),
+                                  Q_ARG(QString, server));
+
+        this->m_descriptions[server] = description;
+    }
+
     bool isSet = this->setCameras(cameras);
+    isSet |= this->setSyphonServers(syphonServers);
     isSet |= this->setDesktops(desktops);
-    isSet |= this->setStreams(cameras + desktops + this->m_uris.keys());
+    isSet |= this->setStreams(cameras + syphonServers + desktops + this->m_uris.keys());
 
     if (!isSet)
         emit this->streamsChanged(this->m_streams);
@@ -558,6 +645,17 @@ bool MediaSource::setCameras(const QStringList &cameras)
     return true;
 }
 
+bool MediaSource::setSyphonServers(const QStringList &servers)
+{
+    if (this->m_syphonServers == servers)
+        return false;
+
+    this->m_syphonServers = servers;
+    emit this->syphonServersChanged(servers);
+
+    return true;
+}
+
 bool MediaSource::setDesktops(const QStringList &desktops)
 {
     if (this->m_desktops == desktops)
@@ -602,6 +700,12 @@ void MediaSource::loadProperties()
                                                         this->m_cameraCapture->property("captureLib")));
     }
 
+    if (this->m_desktopCapture)
+        this->m_desktopCapture->setProperty("captureLib",
+                                            config.value("DesktopCapture.captureLib",
+                                                         this->m_desktopCapture->property("captureLib")));
+
+
     if (this->m_uriCapture)
         this->m_uriCapture->setProperty("codecLib",
                                         config.value("MultiSrc.codecLib",
@@ -684,6 +788,14 @@ void MediaSource::saveVideoCaptureCaptureLib(const QString &captureLib)
     config.endGroup();
 }
 
+void MediaSource::saveDesktopCaptureCaptureLib(const QString &captureLib)
+{
+    QSettings config;
+    config.beginGroup("Libraries");
+    config.setValue("DesktopCapture.captureLib", captureLib);
+    config.endGroup();
+}
+
 void MediaSource::saveMultiSrcCodecLib(const QString &codecLib)
 {
     QSettings config;
@@ -719,6 +831,9 @@ void MediaSource::saveProperties()
         config.setValue("VideoCapture.captureLib", this->m_cameraCapture->property("captureLib"));
     }
 
+    if (this->m_desktopCapture)
+        config.setValue("DesktopCapture.captureLib", this->m_desktopCapture->property("captureLib"));
+
     if (this->m_uriCapture)
         config.setValue("MultiSrc.codecLib", this->m_uriCapture->property("codecLib"));
 
