@@ -1,5 +1,5 @@
 /* Webcamoid, webcam capture application.
- * Copyright (C) 2011-2016  Gonzalo Exequiel Pedone
+ * Copyright (C) 2011-2017  Gonzalo Exequiel Pedone
  *
  * Webcamoid is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -86,18 +86,12 @@ AkCaps &AkCaps::operator =(const QString &other)
 
 bool AkCaps::operator ==(const AkCaps &other) const
 {
-    if (this->toString() == other.toString())
-        return true;
-
-    return false;
+    return this->toString() == other.toString();
 }
 
 bool AkCaps::operator ==(const QString &caps) const
 {
-    if (this->toString() == caps)
-        return true;
-
-    return false;
+    return this->toString() == caps;
 }
 
 bool AkCaps::operator !=(const AkCaps &other) const
@@ -134,7 +128,7 @@ AkCaps &AkCaps::fromMap(const QVariantMap &caps)
 {
     QList<QByteArray> properties = this->dynamicPropertyNames();
 
-    foreach (QByteArray property, properties)
+    for (const QByteArray &property: properties)
         this->setProperty(property, QVariant());
 
     if (!caps.contains("mimeType")) {
@@ -144,7 +138,7 @@ AkCaps &AkCaps::fromMap(const QVariantMap &caps)
         return *this;
     }
 
-    foreach (QString key, caps.keys())
+    for (const QString &key: caps.keys())
         if (key == "mimeType") {
             this->d->m_isValid = QRegExp("\\s*[a-z]+/\\w+(?:(?:-|\\+|\\.)\\w+)*\\s*")
                                  .exactMatch(caps[key].toString());
@@ -163,7 +157,7 @@ AkCaps &AkCaps::fromString(const QString &caps)
 
     QList<QByteArray> properties = this->dynamicPropertyNames();
 
-    foreach (QByteArray property, properties)
+    for (const QByteArray &property: properties)
         this->setProperty(property, QVariant());
 
     QStringList capsChunks;
@@ -193,7 +187,7 @@ QVariantMap AkCaps::toMap() const
     QVariantMap caps;
     caps["mimeType"] = this->d->m_mimeType;
 
-    foreach (QByteArray property, this->dynamicPropertyNames()) {
+    for (const QByteArray &property: this->dynamicPropertyNames()) {
         QString key = QString::fromUtf8(property.constData());
         caps[key] = this->property(property.toStdString().c_str());
     }
@@ -209,12 +203,12 @@ QString AkCaps::toString() const
     QString caps = this->d->m_mimeType;
     QStringList properties;
 
-    foreach (QByteArray property, this->dynamicPropertyNames())
+    for (const QByteArray &property: this->dynamicPropertyNames())
         properties << QString::fromUtf8(property.constData());
 
     properties.sort();
 
-    foreach (QString property, properties)
+    for (const QString &property: properties)
         caps.append(QString(",%1=%2").arg(property)
                                      .arg(this->property(property.toStdString().c_str()).toString()));
 
@@ -226,7 +220,7 @@ AkCaps &AkCaps::update(const AkCaps &other)
     if (this->d->m_mimeType != other.d->m_mimeType)
         return *this;
 
-    foreach (QByteArray property, other.dynamicPropertyNames())
+    for (const QByteArray &property: other.dynamicPropertyNames())
         this->setProperty(property.constData(),
                           other.property(property.constData()));
 
@@ -238,7 +232,7 @@ bool AkCaps::isCompatible(const AkCaps &other) const
     if (this->d->m_mimeType != other.d->m_mimeType)
         return false;
 
-    foreach (QByteArray property, other.dynamicPropertyNames())
+    for (const QByteArray &property: other.dynamicPropertyNames())
         if (!this->dynamicPropertyNames().contains(property) ||
             this->property(property.constData()) != other.property(property.constData()))
             return false;
@@ -275,7 +269,7 @@ void AkCaps::clear()
 
     QList<QByteArray> properties = this->dynamicPropertyNames();
 
-    foreach (QByteArray property, properties)
+    for (const QByteArray &property: properties)
         this->setProperty(property.constData(), QVariant());
 }
 
