@@ -49,7 +49,7 @@ class AKCOMMONS_EXPORT AkCaps: public QObject
             CapsSubtitle
         };
 
-        explicit AkCaps(QObject *parent=NULL);
+        explicit AkCaps(QObject *parent=nullptr);
         AkCaps(const QVariantMap &caps);
         AkCaps(const QString &caps);
         AkCaps(const AkCaps &other);
