@@ -1,5 +1,5 @@
 /* Webcamoid, webcam capture application.
- * Copyright (C) 2011-2016  Gonzalo Exequiel Pedone
+ * Copyright (C) 2011-2017  Gonzalo Exequiel Pedone
  *
  * Webcamoid is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,13 +20,12 @@
 #ifndef ACAPSCONVERTELEMENT_H
 #define ACAPSCONVERTELEMENT_H
 
+#include <QMutex>
 #include <ak.h>
 
-#ifdef USE_GSTREAMER
-#include "gstreamer/convertaudio.h"
-#else
-#include "ffmpeg/convertaudio.h"
-#endif
+#include "convertaudio.h"
+
+typedef QSharedPointer<ConvertAudio> ConvertAudioPtr;
 
 class ACapsConvertElement: public AkElement
 {
@@ -36,24 +35,38 @@ class ACapsConvertElement: public AkElement
                WRITE setCaps
                RESET resetCaps
                NOTIFY capsChanged)
+    Q_PROPERTY(QString convertLib
+               READ convertLib
+               WRITE setConvertLib
+               RESET resetConvertLib
+               NOTIFY convertLibChanged)
 
     public:
         explicit ACapsConvertElement();
 
         Q_INVOKABLE QString caps() const;
+        Q_INVOKABLE QString convertLib() const;
 
     private:
         AkCaps m_caps;
-        ConvertAudio m_convertAudio;
+        ConvertAudioPtr m_convertAudio;
+        QMutex m_mutex;
 
     signals:
         void capsChanged(const QString &caps);
+        void convertLibChanged(const QString &convertLib);
 
     public slots:
         void setCaps(const QString &caps);
+        void setConvertLib(const QString &convertLib);
         void resetCaps();
+        void resetConvertLib();
 
         AkPacket iStream(const AkAudioPacket &packet);
+        bool setState(AkElement::ElementState state);
+
+    private slots:
+        void convertLibUpdated(const QString &convertLib);
 };
 
 #endif // ACAPSCONVERTELEMENT_H
