@@ -29,44 +29,6 @@ AgingElement::AgingElement(): AkElement()
     qsrand(uint(QTime::currentTime().msec()));
 }
 
-QObject *AgingElement::controlInterface(QQmlEngine *engine, const QString &controlId) const
-{
-    Q_UNUSED(controlId)
-
-    if (!engine)
-        return NULL;
-
-    // Load the UI from the plugin.
-    QQmlComponent component(engine, QUrl(QStringLiteral("qrc:/Aging/share/qml/main.qml")));
-
-    if (component.isError()) {
-        qDebug() << "Error in plugin "
-                 << this->metaObject()->className()
-                 << ":"
-                 << component.errorString();
-
-        return NULL;
-    }
-
-    // Create a context for the plugin.
-    QQmlContext *context = new QQmlContext(engine->rootContext());
-    context->setContextProperty("Aging", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
-    context->setContextProperty("controlId", this->objectName());
-
-    // Create an item with the plugin context.
-    QObject *item = component.create(context);
-
-    if (!item) {
-        delete context;
-
-        return NULL;
-    }
-
-    context->setParent(item);
-
-    return item;
-}
-
 int AgingElement::nScratches() const
 {
     return this->m_scratches.size();
@@ -225,6 +187,22 @@ void AgingElement::dusts(QImage &dest)
     }
 }
 
+QString AgingElement::controlInterfaceProvide(const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    return QString("qrc:/Aging/share/qml/main.qml");
+}
+
+void AgingElement::controlInterfaceConfigure(QQmlContext *context,
+                                             const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    context->setContextProperty("Aging", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
+    context->setContextProperty("controlId", this->objectName());
+}
+
 void AgingElement::setNScratches(int nScratches)
 {
     if (this->m_scratches.size() == nScratches)
