@@ -1,5 +1,5 @@
 /* Webcamoid, webcam capture application.
- * Copyright (C) 2011-2016  Gonzalo Exequiel Pedone
+ * Copyright (C) 2011-2017  Gonzalo Exequiel Pedone
  *
  * Webcamoid is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,14 +25,16 @@
 class BinElement: public AkElement
 {
     Q_OBJECT
-
-    Q_PROPERTY(QString description READ description
-                                   WRITE setDescription
-                                   RESET resetDescription)
-
-    Q_PROPERTY(bool blocking READ blocking
-                             WRITE setBlocking
-                             RESET resetBlocking)
+    Q_PROPERTY(QString description
+               READ description
+               WRITE setDescription
+               RESET resetDescription
+               NOTIFY descriptionChanged)
+    Q_PROPERTY(bool blocking
+               READ blocking
+               WRITE setBlocking
+               RESET resetBlocking
+               NOTIFY blockingChanged)
 
     public:
         explicit BinElement();
@@ -51,6 +53,10 @@ class BinElement: public AkElement
         QList<AkElementPtr> m_outputs;
         Pipeline m_pipelineDescription;
 
+    signals:
+        void descriptionChanged(const QString &description);
+        void blockingChanged(bool blocking);
+
     public slots:
         void setDescription(const QString &description);
         void setBlocking(bool blocking);
