@@ -20,8 +20,6 @@
 #ifndef CARTOONELEMENT_H
 #define CARTOONELEMENT_H
 
-#include <QQmlComponent>
-#include <QQmlContext>
 #include <QMutex>
 #include <ak.h>
 #include <akutils.h>
@@ -69,9 +67,6 @@ class CartoonElement: public AkElement
         explicit CartoonElement();
         ~CartoonElement();
 
-        Q_INVOKABLE QObject *controlInterface(QQmlEngine *engine,
-                                              const QString &controlId) const;
-
         Q_INVOKABLE int ncolors() const;
         Q_INVOKABLE int colorDiff() const;
         Q_INVOKABLE bool showEdges() const;
@@ -124,6 +119,11 @@ class CartoonElement: public AkElement
             return qRgb(r, g, b);
         }
 
+    protected:
+        QString controlInterfaceProvide(const QString &controlId) const;
+        void controlInterfaceConfigure(QQmlContext *context,
+                                       const QString &controlId) const;
+
     signals:
         void ncolorsChanged(int ncolors);
         void colorDiffChanged(int colorDiff);
