@@ -20,8 +20,6 @@
 #ifndef CHANGEHSLELEMENT_H
 #define CHANGEHSLELEMENT_H
 
-#include <QQmlComponent>
-#include <QQmlContext>
 #include <ak.h>
 #include <akutils.h>
 
@@ -37,14 +35,16 @@ class ChangeHSLElement: public AkElement
     public:
         explicit ChangeHSLElement();
 
-        Q_INVOKABLE QObject *controlInterface(QQmlEngine *engine,
-                                              const QString &controlId) const;
-
         Q_INVOKABLE QVariantList kernel() const;
 
     private:
         QVector<qreal> m_kernel;
 
+    protected:
+        QString controlInterfaceProvide(const QString &controlId) const;
+        void controlInterfaceConfigure(QQmlContext *context,
+                                       const QString &controlId) const;
+
     signals:
         void kernelChanged(const QVariantList &kernel);
 
