@@ -123,44 +123,6 @@ CharifyElement::CharifyElement(): AkElement()
                      &CharifyElement::updateCharTable);
 }
 
-QObject *CharifyElement::controlInterface(QQmlEngine *engine, const QString &controlId) const
-{
-    Q_UNUSED(controlId)
-
-    if (!engine)
-        return NULL;
-
-    // Load the UI from the plugin.
-    QQmlComponent component(engine, QUrl(QStringLiteral("qrc:/Charify/share/qml/main.qml")));
-
-    if (component.isError()) {
-        qDebug() << "Error in plugin "
-                 << this->metaObject()->className()
-                 << ":"
-                 << component.errorString();
-
-        return NULL;
-    }
-
-    // Create a context for the plugin.
-    QQmlContext *context = new QQmlContext(engine->rootContext());
-    context->setContextProperty("Charify", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
-    context->setContextProperty("controlId", this->objectName());
-
-    // Create an item with the plugin context.
-    QObject *item = component.create(context);
-
-    if (!item) {
-        delete context;
-
-        return NULL;
-    }
-
-    context->setParent(item);
-
-    return item;
-}
-
 QString CharifyElement::mode() const
 {
     return colorModeToStr->value(this->m_mode);
@@ -262,6 +224,21 @@ bool CharifyElement::chrLessThan(const Character &chr1, const Character &chr2)
     return chr1.weight < chr2.weight;
 }
 
+QString CharifyElement::controlInterfaceProvide(const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    return QString("qrc:/Charify/share/qml/main.qml");
+}
+
+void CharifyElement::controlInterfaceConfigure(QQmlContext *context, const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    context->setContextProperty("Charify", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
+    context->setContextProperty("controlId", this->objectName());
+}
+
 void CharifyElement::setMode(const QString &mode)
 {
     ColorMode modeEnum = colorModeToStr->key(mode, ColorModeNatural);
@@ -488,7 +465,7 @@ void CharifyElement::updateCharTable()
     }
 
     this->m_characters.resize(256);
-    qSort(characters.begin(), characters.end(), this->chrLessThan);
+    std::sort(characters.begin(), characters.end(), this->chrLessThan);
 
     for (int i = 0; i < 256; i++) {
         int c = i * (characters.size() - 1) / 255;
