@@ -29,44 +29,6 @@ ColorFilterElement::ColorFilterElement(): AkElement()
     this->m_disable = false;
 }
 
-QObject *ColorFilterElement::controlInterface(QQmlEngine *engine, const QString &controlId) const
-{
-    Q_UNUSED(controlId)
-
-    if (!engine)
-        return NULL;
-
-    // Load the UI from the plugin.
-    QQmlComponent component(engine, QUrl(QStringLiteral("qrc:/ColorFilter/share/qml/main.qml")));
-
-    if (component.isError()) {
-        qDebug() << "Error in plugin "
-                 << this->metaObject()->className()
-                 << ":"
-                 << component.errorString();
-
-        return NULL;
-    }
-
-    // Create a context for the plugin.
-    QQmlContext *context = new QQmlContext(engine->rootContext());
-    context->setContextProperty("ColorFilter", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
-    context->setContextProperty("controlId", this->objectName());
-
-    // Create an item with the plugin context.
-    QObject *item = component.create(context);
-
-    if (!item) {
-        delete context;
-
-        return NULL;
-    }
-
-    context->setParent(item);
-
-    return item;
-}
-
 QRgb ColorFilterElement::color() const
 {
     return this->m_color;
@@ -87,6 +49,22 @@ bool ColorFilterElement::disable() const
     return this->m_disable;
 }
 
+QString ColorFilterElement::controlInterfaceProvide(const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    return QString("qrc:/ColorFilter/share/qml/main.qml");
+}
+
+void ColorFilterElement::controlInterfaceConfigure(QQmlContext *context,
+                                                   const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    context->setContextProperty("ColorFilter", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
+    context->setContextProperty("controlId", this->objectName());
+}
+
 void ColorFilterElement::setColor(QRgb color)
 {
     if (this->m_color == color)
