@@ -29,44 +29,6 @@ ColorReplaceElement::ColorReplaceElement(): AkElement()
     this->m_disable = false;
 }
 
-QObject *ColorReplaceElement::controlInterface(QQmlEngine *engine, const QString &controlId) const
-{
-    Q_UNUSED(controlId)
-
-    if (!engine)
-        return NULL;
-
-    // Load the UI from the plugin.
-    QQmlComponent component(engine, QUrl(QStringLiteral("qrc:/ColorReplace/share/qml/main.qml")));
-
-    if (component.isError()) {
-        qDebug() << "Error in plugin "
-                 << this->metaObject()->className()
-                 << ":"
-                 << component.errorString();
-
-        return NULL;
-    }
-
-    // Create a context for the plugin.
-    QQmlContext *context = new QQmlContext(engine->rootContext());
-    context->setContextProperty("ColorReplace", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
-    context->setContextProperty("controlId", this->objectName());
-
-    // Create an item with the plugin context.
-    QObject *item = component.create(context);
-
-    if (!item) {
-        delete context;
-
-        return NULL;
-    }
-
-    context->setParent(item);
-
-    return item;
-}
-
 QRgb ColorReplaceElement::from() const
 {
     return this->m_from;
@@ -87,6 +49,22 @@ bool ColorReplaceElement::disable() const
     return this->m_disable;
 }
 
+QString ColorReplaceElement::controlInterfaceProvide(const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    return QString("qrc:/ColorReplace/share/qml/main.qml");
+}
+
+void ColorReplaceElement::controlInterfaceConfigure(QQmlContext *context,
+                                                    const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    context->setContextProperty("ColorReplace", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
+    context->setContextProperty("controlId", this->objectName());
+}
+
 void ColorReplaceElement::setFrom(QRgb from)
 {
     if (this->m_from == from)
