@@ -21,8 +21,6 @@
 #define DENOISEELEMENT_H
 
 #include <QtMath>
-#include <QQmlComponent>
-#include <QQmlContext>
 #include <ak.h>
 #include <akutils.h>
 
@@ -56,9 +54,6 @@ class DenoiseElement: public AkElement
         explicit DenoiseElement();
         ~DenoiseElement();
 
-        Q_INVOKABLE QObject *controlInterface(QQmlEngine *engine,
-                                              const QString &controlId) const;
-
         Q_INVOKABLE int radius() const;
         Q_INVOKABLE int factor() const;
         Q_INVOKABLE int mu() const;
@@ -100,6 +95,11 @@ class DenoiseElement: public AkElement
         static void denoise(const DenoiseStaticParams &staticParams,
                             const DenoiseParams *params);
 
+    protected:
+        QString controlInterfaceProvide(const QString &controlId) const;
+        void controlInterfaceConfigure(QQmlContext *context,
+                                       const QString &controlId) const;
+
     signals:
         void radiusChanged(int radius);
         void factorChanged(int factor);
