@@ -29,44 +29,6 @@ DizzyElement::DizzyElement(): AkElement()
     this->m_strength = 0.75;
 }
 
-QObject *DizzyElement::controlInterface(QQmlEngine *engine, const QString &controlId) const
-{
-    Q_UNUSED(controlId)
-
-    if (!engine)
-        return NULL;
-
-    // Load the UI from the plugin.
-    QQmlComponent component(engine, QUrl(QStringLiteral("qrc:/Dizzy/share/qml/main.qml")));
-
-    if (component.isError()) {
-        qDebug() << "Error in plugin "
-                 << this->metaObject()->className()
-                 << ":"
-                 << component.errorString();
-
-        return NULL;
-    }
-
-    // Create a context for the plugin.
-    QQmlContext *context = new QQmlContext(engine->rootContext());
-    context->setContextProperty("Dizzy", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
-    context->setContextProperty("controlId", this->objectName());
-
-    // Create an item with the plugin context.
-    QObject *item = component.create(context);
-
-    if (!item) {
-        delete context;
-
-        return NULL;
-    }
-
-    context->setParent(item);
-
-    return item;
-}
-
 qreal DizzyElement::speed() const
 {
     return this->m_speed;
@@ -82,6 +44,22 @@ qreal DizzyElement::strength() const
     return this->m_strength;
 }
 
+QString DizzyElement::controlInterfaceProvide(const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    return QString("qrc:/Dizzy/share/qml/main.qml");
+}
+
+void DizzyElement::controlInterfaceConfigure(QQmlContext *context,
+                                             const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    context->setContextProperty("Dizzy", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
+    context->setContextProperty("controlId", this->objectName());
+}
+
 void DizzyElement::setSpeed(qreal speed)
 {
     if (qFuzzyCompare(this->m_speed, speed))
