@@ -1,5 +1,5 @@
 /* Webcamoid, webcam capture application.
- * Copyright (C) 2011-2016  Gonzalo Exequiel Pedone
+ * Copyright (C) 2011-2017  Gonzalo Exequiel Pedone
  *
  * Webcamoid is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,8 +14,7 @@
  * You should have received a copy of the GNU General Public License
  * along with Webcamoid. If not, see <http://www.gnu.org/licenses/>.
  *
- * Email   : hipersayan DOT x AT gmail DOT com
- * Web-Site: http://github.com/hipersayanX/webcamoid
+ * Web-Site: http://webcamoid.github.io/
  */
 
 #ifndef EQUALIZEELEMENT_H
@@ -24,6 +23,8 @@
 #include <ak.h>
 #include <akutils.h>
 
+#include "pixelstructs.h"
+
 class EqualizeElement: public AkElement
 {
     Q_OBJECT
@@ -31,6 +32,11 @@ class EqualizeElement: public AkElement
     public:
         explicit EqualizeElement();
 
+    private:
+        QVector<quint64> histogram(const QImage &img) const;
+        QVector<quint64> cumulativeHistogram(const QVector<quint64> &histogram) const;
+        QVector<quint8> equalizationTable(const QImage &img) const;
+
     public slots:
         AkPacket iStream(const AkPacket &packet);
 };
