@@ -31,44 +31,6 @@ FalseColorElement::FalseColorElement(): AkElement()
     this->m_soft = false;
 }
 
-QObject *FalseColorElement::controlInterface(QQmlEngine *engine, const QString &controlId) const
-{
-    Q_UNUSED(controlId)
-
-    if (!engine)
-        return NULL;
-
-    // Load the UI from the plugin.
-    QQmlComponent component(engine, QUrl(QStringLiteral("qrc:/FalseColor/share/qml/main.qml")));
-
-    if (component.isError()) {
-        qDebug() << "Error in plugin "
-                 << this->metaObject()->className()
-                 << ":"
-                 << component.errorString();
-
-        return NULL;
-    }
-
-    // Create a context for the plugin.
-    QQmlContext *context = new QQmlContext(engine->rootContext());
-    context->setContextProperty("FalseColor", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
-    context->setContextProperty("controlId", this->objectName());
-
-    // Create an item with the plugin context.
-    QObject *item = component.create(context);
-
-    if (!item) {
-        delete context;
-
-        return NULL;
-    }
-
-    context->setParent(item);
-
-    return item;
-}
-
 QVariantList FalseColorElement::table() const
 {
     QVariantList table;
@@ -84,6 +46,22 @@ bool FalseColorElement::soft() const
     return this->m_soft;
 }
 
+QString FalseColorElement::controlInterfaceProvide(const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    return QString("qrc:/FalseColor/share/qml/main.qml");
+}
+
+void FalseColorElement::controlInterfaceConfigure(QQmlContext *context,
+                                                  const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    context->setContextProperty("FalseColor", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
+    context->setContextProperty("controlId", this->objectName());
+}
+
 void FalseColorElement::setTable(const QVariantList &table)
 {
     QList<QRgb> tableRgb;
