@@ -41,47 +41,6 @@ HalftoneElement::HalftoneElement(): AkElement()
                      &HalftoneElement::updatePattern);
 }
 
-QObject *HalftoneElement::controlInterface(QQmlEngine *engine, const QString &controlId) const
-{
-    Q_UNUSED(controlId)
-
-    if (!engine)
-        return NULL;
-
-    // Load the UI from the plugin.
-    QQmlComponent component(engine, QUrl(QStringLiteral("qrc:/Halftone/share/qml/main.qml")));
-
-    if (component.isError()) {
-        qDebug() << "Error in plugin "
-                 << this->metaObject()->className()
-                 << ":"
-                 << component.errorString();
-
-        return NULL;
-    }
-
-    // Create a context for the plugin.
-    QQmlContext *context = new QQmlContext(engine->rootContext());
-    context->setContextProperty("Halftone", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
-    context->setContextProperty("controlId", this->objectName());
-
-    QStringList picturesPath = QStandardPaths::standardLocations(QStandardPaths::PicturesLocation);
-    context->setContextProperty("picturesPath", picturesPath[0]);
-
-    // Create an item with the plugin context.
-    QObject *item = component.create(context);
-
-    if (!item) {
-        delete context;
-
-        return NULL;
-    }
-
-    context->setParent(item);
-
-    return item;
-}
-
 QString HalftoneElement::pattern() const
 {
     return this->m_pattern;
@@ -149,6 +108,25 @@ void HalftoneElement::updatePattern()
     this->m_mutex.unlock();
 }
 
+QString HalftoneElement::controlInterfaceProvide(const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    return QString("qrc:/Halftone/share/qml/main.qml");
+}
+
+void HalftoneElement::controlInterfaceConfigure(QQmlContext *context,
+                                                const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    context->setContextProperty("Halftone", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
+    context->setContextProperty("controlId", this->objectName());
+
+    QStringList picturesPath = QStandardPaths::standardLocations(QStandardPaths::PicturesLocation);
+    context->setContextProperty("picturesPath", picturesPath[0]);
+}
+
 void HalftoneElement::setPattern(const QString &pattern)
 {
     if (this->m_pattern == pattern)
