@@ -113,44 +113,6 @@ MatrixElement::MatrixElement(): AkElement()
                      &MatrixElement::updateCharTable);
 }
 
-QObject *MatrixElement::controlInterface(QQmlEngine *engine, const QString &controlId) const
-{
-    Q_UNUSED(controlId)
-
-    if (!engine)
-        return NULL;
-
-    // Load the UI from the plugin.
-    QQmlComponent component(engine, QUrl(QStringLiteral("qrc:/Matrix/share/qml/main.qml")));
-
-    if (component.isError()) {
-        qDebug() << "Error in plugin "
-                 << this->metaObject()->className()
-                 << ":"
-                 << component.errorString();
-
-        return NULL;
-    }
-
-    // Create a context for the plugin.
-    QQmlContext *context = new QQmlContext(engine->rootContext());
-    context->setContextProperty("Matrix", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
-    context->setContextProperty("controlId", this->objectName());
-
-    // Create an item with the plugin context.
-    QObject *item = component.create(context);
-
-    if (!item) {
-        delete context;
-
-        return NULL;
-    }
-
-    context->setParent(item);
-
-    return item;
-}
-
 int MatrixElement::nDrops() const
 {
     return this->m_nDrops;
@@ -328,6 +290,22 @@ QImage MatrixElement::renderRain(const QSize &frameSize,
     return rain;
 }
 
+QString MatrixElement::controlInterfaceProvide(const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    return QString("qrc:/Matrix/share/qml/main.qml");
+}
+
+void MatrixElement::controlInterfaceConfigure(QQmlContext *context,
+                                              const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    context->setContextProperty("Matrix", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
+    context->setContextProperty("controlId", this->objectName());
+}
+
 void MatrixElement::setNDrops(int nDrops)
 {
     if (this->m_nDrops == nDrops)
@@ -621,7 +599,7 @@ void MatrixElement::updateCharTable()
         characters.append(Character(chr, QImage(), weight));
     }
 
-    qSort(characters.begin(), characters.end(), this->chrLessThan);
+    std::sort(characters.begin(), characters.end(), this->chrLessThan);
 
     this->m_characters.clear();
 
