@@ -27,45 +27,6 @@ MatrixTransformElement::MatrixTransformElement(): AkElement()
     };
 }
 
-QObject *MatrixTransformElement::controlInterface(QQmlEngine *engine,
-                                                  const QString &controlId) const
-{
-    Q_UNUSED(controlId)
-
-    if (!engine)
-        return NULL;
-
-    // Load the UI from the plugin.
-    QQmlComponent component(engine, QUrl(QStringLiteral("qrc:/MatrixTransform/share/qml/main.qml")));
-
-    if (component.isError()) {
-        qDebug() << "Error in plugin "
-                 << this->metaObject()->className()
-                 << ":"
-                 << component.errorString();
-
-        return NULL;
-    }
-
-    // Create a context for the plugin.
-    QQmlContext *context = new QQmlContext(engine->rootContext());
-    context->setContextProperty("MatrixTransform", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
-    context->setContextProperty("controlId", this->objectName());
-
-    // Create an item with the plugin context.
-    QObject *item = component.create(context);
-
-    if (!item) {
-        delete context;
-
-        return NULL;
-    }
-
-    context->setParent(item);
-
-    return item;
-}
-
 QVariantList MatrixTransformElement::kernel() const
 {
     QVariantList kernel;
@@ -76,6 +37,22 @@ QVariantList MatrixTransformElement::kernel() const
     return kernel;
 }
 
+QString MatrixTransformElement::controlInterfaceProvide(const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    return QString("qrc:/MatrixTransform/share/qml/main.qml");
+}
+
+void MatrixTransformElement::controlInterfaceConfigure(QQmlContext *context,
+                                                       const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    context->setContextProperty("MatrixTransform", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
+    context->setContextProperty("controlId", this->objectName());
+}
+
 void MatrixTransformElement::setKernel(const QVariantList &kernel)
 {
     QVector<qreal> k;
