@@ -48,7 +48,6 @@ MediaSourceFFmpeg::MediaSourceFFmpeg(QObject *parent):
     MediaSource(parent)
 {
     av_register_all();
-    avdevice_register_all();
     avformat_network_init();
 
     this->m_loop = false;
@@ -61,6 +60,9 @@ MediaSourceFFmpeg::MediaSourceFFmpeg(QObject *parent):
 #ifndef QT_DEBUG
     av_log_set_level(AV_LOG_QUIET);
 #endif
+
+    if (this->m_threadPool.maxThreadCount() < 2)
+        this->m_threadPool.setMaxThreadCount(2);
 }
 
 MediaSourceFFmpeg::~MediaSourceFFmpeg()
@@ -130,7 +132,7 @@ QString MediaSourceFFmpeg::streamLanguage(int stream)
     }
 
     AVDictionary *metadata = this->m_inputContext->streams[stream]->metadata;
-    AVDictionaryEntry *dicEntry = NULL;
+    AVDictionaryEntry *dicEntry = nullptr;
     QString language;
 
     while ((dicEntry = av_dict_get(metadata, "", dicEntry, AV_DICT_IGNORE_SUFFIX))) {
@@ -203,7 +205,7 @@ AkCaps MediaSourceFFmpeg::caps(int stream)
         if (!this->initContext())
             return AkCaps();
 
-        if (avformat_find_stream_info(this->m_inputContext.data(), NULL) < 0) {
+        if (avformat_find_stream_info(this->m_inputContext.data(), nullptr) < 0) {
             this->m_inputContext.clear();
 
             return AkCaps();
@@ -281,14 +283,14 @@ AbstractStreamPtr MediaSourceFFmpeg::createStream(int index, bool noModify)
     return stream;
 }
 
-void MediaSourceFFmpeg::readPackets(MediaSourceFFmpeg *element)
+void MediaSourceFFmpeg::readPackets()
 {
-    while (element->m_run) {
-        element->m_dataMutex.lock();
+    while (this->m_run) {
+        this->m_dataMutex.lock();
 
-        if (element->packetQueueSize() >= element->m_maxPacketQueueSize)
-            if (!element->m_packetQueueNotFull.wait(&element->m_dataMutex, THREAD_WAIT_LIMIT)) {
-                element->m_dataMutex.unlock();
+        if (this->packetQueueSize() >= this->m_maxPacketQueueSize)
+            if (!this->m_packetQueueNotFull.wait(&this->m_dataMutex, THREAD_WAIT_LIMIT)) {
+                this->m_dataMutex.unlock();
 
                 continue;
             }
@@ -296,13 +298,13 @@ void MediaSourceFFmpeg::readPackets(MediaSourceFFmpeg *element)
         AVPacket *packet = new AVPacket();
         av_init_packet(packet);
         bool notuse = true;
-        int r = av_read_frame(element->m_inputContext.data(), packet);
+        int r = av_read_frame(this->m_inputContext.data(), packet);
 
         if (r >= 0) {
-            if (element->m_streamsMap.contains(packet->stream_index)
-                && (element->m_streams.isEmpty()
-                    || element->m_streams.contains(packet->stream_index))) {
-                element->m_streamsMap[packet->stream_index]->packetEnqueue(packet);
+            if (this->m_streamsMap.contains(packet->stream_index)
+                && (this->m_streams.isEmpty()
+                    || this->m_streams.contains(packet->stream_index))) {
+                this->m_streamsMap[packet->stream_index]->packetEnqueue(packet);
                 notuse = false;
             }
         }
@@ -317,29 +319,29 @@ void MediaSourceFFmpeg::readPackets(MediaSourceFFmpeg *element)
         }
 
         if (r < 0) {
-            if (element->loop()) {
-                for (const AbstractStreamPtr &stream: element->m_streamsMap.values())
-                    stream->packetEnqueue(NULL);
+            if (this->loop()) {
+                for (const AbstractStreamPtr &stream: this->m_streamsMap.values())
+                    stream->packetEnqueue(nullptr);
             }
 
-            element->m_run = false;
+            this->m_run = false;
         }
 
-        element->m_dataMutex.unlock();
+        this->m_dataMutex.unlock();
     }
 }
 
-void MediaSourceFFmpeg::unlockQueue(MediaSourceFFmpeg *element)
+void MediaSourceFFmpeg::unlockQueue()
 {
-    element->m_dataMutex.lock();
+    this->m_dataMutex.lock();
 
-    if (element->packetQueueSize() < element->m_maxPacketQueueSize)
-        element->m_packetQueueNotFull.wakeAll();
+    if (this->packetQueueSize() < this->m_maxPacketQueueSize)
+        this->m_packetQueueNotFull.wakeAll();
 
-    if (element->packetQueueSize() < 1)
-        element->m_packetQueueEmpty.wakeAll();
+    if (this->packetQueueSize() < 1)
+        this->m_packetQueueEmpty.wakeAll();
 
-    element->m_dataMutex.unlock();
+    this->m_dataMutex.unlock();
 }
 
 void MediaSourceFFmpeg::setMedia(const QString &media)
@@ -433,7 +435,7 @@ bool MediaSourceFFmpeg::setState(AkElement::ElementState state)
                 return false;
 
             if (avformat_find_stream_info(this->m_inputContext.data(),
-                                          NULL) < 0) {
+                                          nullptr) < 0) {
                 this->m_inputContext.clear();
 
                 return false;
@@ -494,8 +496,8 @@ bool MediaSourceFFmpeg::setState(AkElement::ElementState state)
             this->m_run = true;
             this->m_readPacketsLoopResult =
                     QtConcurrent::run(&this->m_threadPool,
-                                      this->readPackets,
-                                      this);
+                                      this,
+                                      &MediaSourceFFmpeg::readPackets);
             this->m_curState = state;
 
             return true;
@@ -593,7 +595,9 @@ void MediaSourceFFmpeg::doLoop()
 
 void MediaSourceFFmpeg::packetConsumed()
 {
-    QtConcurrent::run(&this->m_threadPool, this->unlockQueue, this);
+    QtConcurrent::run(&this->m_threadPool,
+                      this,
+                      &MediaSourceFFmpeg::unlockQueue);
 }
 
 bool MediaSourceFFmpeg::initContext()
@@ -603,8 +607,8 @@ bool MediaSourceFFmpeg::initContext()
     if (uri.isEmpty())
         return false;
 
-    AVInputFormat *inputFormat = NULL;
-    AVDictionary *inputOptions = NULL;
+    AVInputFormat *inputFormat = nullptr;
+    AVDictionary *inputOptions = nullptr;
 
     if (QRegExp("/dev/video\\d*").exactMatch(uri))
         inputFormat = av_find_input_format("v4l2");
@@ -632,7 +636,7 @@ bool MediaSourceFFmpeg::initContext()
     QStringList mmsSchemes;
     mmsSchemes << "mms://" << "mmsh://" << "mmst://";
 
-    AVFormatContext *inputContext = NULL;
+    AVFormatContext *inputContext = nullptr;
 
     for (const QString &scheme: mmsSchemes) {
         QString uriCopy = uri;
@@ -641,7 +645,7 @@ bool MediaSourceFFmpeg::initContext()
             uriCopy.replace(QRegExp(QString("^%1").arg(schemer)),
                             scheme);
 
-        inputContext = NULL;
+        inputContext = nullptr;
 
         if (avformat_open_input(&inputContext,
                                 uriCopy.toStdString().c_str(),
