@@ -52,46 +52,7 @@ MultiSrcElement::~MultiSrcElement()
     this->setState(AkElement::ElementStateNull);
 }
 
-QObject *MultiSrcElement::controlInterface(QQmlEngine *engine,
-                                           const QString &controlId) const
-{
-    Q_UNUSED(controlId)
-
-    if (!engine)
-        return NULL;
-
-    // Load the UI from the plugin.
-    QQmlComponent component(engine, QUrl(QStringLiteral("qrc:/MultiSrc/share/qml/main.qml")));
-
-    if (component.isError()) {
-        qDebug() << "Error in plugin "
-                 << this->metaObject()->className()
-                 << ":"
-                 << component.errorString();
-
-        return NULL;
-    }
-
-    // Create a context for the plugin.
-    QQmlContext *context = new QQmlContext(engine->rootContext());
-    context->setContextProperty("MultiSrc", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
-    context->setContextProperty("controlId", this->objectName());
-
-    // Create an item with the plugin context.
-    QObject *item = component.create(context);
-
-    if (!item) {
-        delete context;
-
-        return NULL;
-    }
-
-    context->setParent(item);
-
-    return item;
-}
-
-QStringList MultiSrcElement::medias() const
+QStringList MultiSrcElement::medias()
 {
     return this->m_mediaSource->medias();
 }
@@ -126,7 +87,7 @@ int MultiSrcElement::defaultStream(const QString &mimeType)
     return this->m_mediaSource->defaultStream(mimeType);
 }
 
-QString MultiSrcElement::description(const QString &media) const
+QString MultiSrcElement::description(const QString &media)
 {
     return this->m_mediaSource->description(media);
 }
@@ -151,6 +112,22 @@ QString MultiSrcElement::codecLib() const
     return globalMultiSrc->codecLib();
 }
 
+QString MultiSrcElement::controlInterfaceProvide(const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    return QString("qrc:/MultiSrc/share/qml/main.qml");
+}
+
+void MultiSrcElement::controlInterfaceConfigure(QQmlContext *context,
+                                                const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    context->setContextProperty("MultiSrc", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
+    context->setContextProperty("controlId", this->objectName());
+}
+
 void MultiSrcElement::setMedia(const QString &media)
 {
     this->m_mediaSource->setMedia(media);
