@@ -55,44 +55,6 @@ RadioactiveElement::RadioactiveElement(): AkElement()
                      SIGNAL(blurChanged(int)));
 }
 
-QObject *RadioactiveElement::controlInterface(QQmlEngine *engine, const QString &controlId) const
-{
-    Q_UNUSED(controlId)
-
-    if (!engine)
-        return NULL;
-
-    // Load the UI from the plugin.
-    QQmlComponent component(engine, QUrl(QStringLiteral("qrc:/Radioactive/share/qml/main.qml")));
-
-    if (component.isError()) {
-        qDebug() << "Error in plugin "
-                 << this->metaObject()->className()
-                 << ":"
-                 << component.errorString();
-
-        return NULL;
-    }
-
-    // Create a context for the plugin.
-    QQmlContext *context = new QQmlContext(engine->rootContext());
-    context->setContextProperty("Radioactive", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
-    context->setContextProperty("controlId", this->objectName());
-
-    // Create an item with the plugin context.
-    QObject *item = component.create(context);
-
-    if (!item) {
-        delete context;
-
-        return NULL;
-    }
-
-    context->setParent(item);
-
-    return item;
-}
-
 QString RadioactiveElement::mode() const
 {
     return radiationModeToStr->value(this->m_mode);
@@ -214,6 +176,22 @@ QImage RadioactiveElement::imageAlphaDiff(const QImage &src, int alphaDiff)
     return dest;
 }
 
+QString RadioactiveElement::controlInterfaceProvide(const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    return QString("qrc:/Radioactive/share/qml/main.qml");
+}
+
+void RadioactiveElement::controlInterfaceConfigure(QQmlContext *context,
+                                                   const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    context->setContextProperty("Radioactive", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
+    context->setContextProperty("controlId", this->objectName());
+}
+
 void RadioactiveElement::setMode(const QString &mode)
 {
     RadiationMode modeEnum = radiationModeToStr->key(mode,
