@@ -26,44 +26,6 @@ ShagadelicElement::ShagadelicElement(): AkElement()
     this->m_mask = 0xffffff;
 }
 
-QObject *ShagadelicElement::controlInterface(QQmlEngine *engine, const QString &controlId) const
-{
-    Q_UNUSED(controlId)
-
-    if (!engine)
-        return NULL;
-
-    // Load the UI from the plugin.
-    QQmlComponent component(engine, QUrl(QStringLiteral("qrc:/Shagadelic/share/qml/main.qml")));
-
-    if (component.isError()) {
-        qDebug() << "Error in plugin "
-                 << this->metaObject()->className()
-                 << ":"
-                 << component.errorString();
-
-        return NULL;
-    }
-
-    // Create a context for the plugin.
-    QQmlContext *context = new QQmlContext(engine->rootContext());
-    context->setContextProperty("Shagadelic", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
-    context->setContextProperty("controlId", this->objectName());
-
-    // Create an item with the plugin context.
-    QObject *item = component.create(context);
-
-    if (!item) {
-        delete context;
-
-        return NULL;
-    }
-
-    context->setParent(item);
-
-    return item;
-}
-
 quint32 ShagadelicElement::mask() const
 {
     return this->m_mask;
@@ -125,6 +87,22 @@ void ShagadelicElement::init(const QSize &size)
     this->m_phase = 0;
 }
 
+QString ShagadelicElement::controlInterfaceProvide(const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    return QString("qrc:/Shagadelic/share/qml/main.qml");
+}
+
+void ShagadelicElement::controlInterfaceConfigure(QQmlContext *context,
+                                                  const QString &controlId) const
+{
+    Q_UNUSED(controlId)
+
+    context->setContextProperty("Shagadelic", const_cast<QObject *>(qobject_cast<const QObject *>(this)));
+    context->setContextProperty("controlId", this->objectName());
+}
+
 void ShagadelicElement::setMask(quint32 mask)
 {
     if (this->m_mask == mask)
