@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 
 if [ -z "${DISABLE_CCACHE}" ]; then
     if [ "${CXX}" = clang++ ]; then
@@ -10,7 +10,7 @@ else
     COMPILER=${CXX}
 fi
 
-if [ "${TRAVIS_OS_NAME}" = linux ]; then
+if [ "${TRAVIS_OS_NAME}" = linux ] && [ -z "${ANDROID_BUILD}" ]; then
     EXEC="docker exec ${DOCKERSYS}"
 fi
 
@@ -22,13 +22,18 @@ if [ "${DOCKERIMG}" = ubuntu:trusty ] || \
 #!/bin/bash
 
 source /opt/qt58/bin/qt58-env.sh
-
 EOF
 
     chmod +x ${BUILDSCRIPT}
 fi
 
-if [ "${TRAVIS_OS_NAME}" = linux ]; then
+if [ "${ANDROID_BUILD}" = 1 ]; then
+    export PATH=$PWD/build/Qt/${QTVER:0:3}/android_${TARGET_ARCH}/bin:$PATH
+    export ANDROID_NDK_ROOT=$PWD/build/android-ndk-${NDKVER}
+    qmake -spec ${COMPILESPEC} Webcamoid.pro
+elif [ "${TRAVIS_OS_NAME}" = linux ]; then
+    export PATH=$HOME/.local/bin:$PATH
+
     if [ "${DOCKERSYS}" = debian ]; then
         if [ "${DOCKERIMG}" = ubuntu:trusty ] || \
            [ "${DOCKERIMG}" = ubuntu:xenial ]; then
@@ -46,13 +51,18 @@ EOF
             QMAKE_CXX="${COMPILER}"
     fi
 elif [ "${TRAVIS_OS_NAME}" = osx ]; then
+    syphonFPath="$PWD/Syphon"
+
     ${EXEC} qmake -spec ${COMPILESPEC} Webcamoid.pro \
         QMAKE_CXX="${COMPILER}" \
+        SYPHONINCLUDES="$syphonFPath/Syphon.framework/Headers" \
+        SYPHONLIBS=-F"$syphonFPath" \
+        SYPHONLIBS+=-framework \
+        SYPHONLIBS+=Syphon \
         LIBUSBINCLUDES=/usr/local/opt/libusb/include \
         LIBUVCINCLUDES=/usr/local/opt/libuvc/include \
         LIBUVCLIBS=-L/usr/local/opt/libuvc/lib \
         LIBUVCLIBS+=-luvc
-
 fi
 
 if [ -z "${NJOBS}" ]; then
